import 'dart:convert';
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:f_k_chart/f_k_chart.dart';
void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.green,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  List<KLineEntity> datas= [];
  bool showLoading = true;
  MainState _mainState = MainState.BOLL;
  bool _volHidden = false;
  SecondaryState _secondaryState = SecondaryState.MACD;
  bool isLine = true;
  bool isChinese = true;
  bool _hideGrid = false;
  bool _showNowPrice = true;
  bool isChangeUI = false;
  String uniqueMark;

  @override
  void initState() {
    super.initState();
    getData('1day');

  }


  @override
  Widget build(BuildContext context) {
    return ListView(
      shrinkWrap: true,
      children: <Widget>[
        Stack(children: <Widget>[
          Container(
            height: 450,
            width: double.infinity,
            child:  KlineScrollWidget(
              datas,
              isLine: isLine,
              pointWidth: 1.3,
              canScale: isLine ? false : true,
              maxRectWidth: isLine ? null : 15.0,
              minRectWidth: isLine ? null : 4.0,
              mainState: _mainState,
              secondaryState: _secondaryState,
              edge: EdgeInsets.only(right:  0.0),
              userFriendlyMinPointWidth:
                  8,
              uniqueMark: uniqueMark,
            ),
          ),
          if (showLoading)
            Container(
                width: double.infinity,
                height: 450,
                alignment: Alignment.center,
                child: const CircularProgressIndicator()),
        ]),
        buildButtons(),
      ],
    );
  }

  Widget buildButtons() {
    return Wrap(
      alignment: WrapAlignment.spaceEvenly,
      children: <Widget>[
        button("Time Mode", onPressed: () => isLine = true),
        button("K Line Mode", onPressed: () => isLine = false),
        button("Line:MA", onPressed: () => _mainState = MainState.MA),
        button("Line:BOLL", onPressed: () => _mainState = MainState.BOLL),
        button("Hide Line", onPressed: () => _mainState = MainState.NONE),
        button("Secondary Chart:MACD", onPressed: () => _secondaryState = SecondaryState.MACD),
        button("Secondary Chart:KDJ", onPressed: () => _secondaryState = SecondaryState.KDJ),
        button("Secondary Chart:RSI", onPressed: () => _secondaryState = SecondaryState.RSI),
        button("Secondary Chart:WR", onPressed: () => _secondaryState = SecondaryState.WR),
        button("Secondary Chart:Hide", onPressed: () => _secondaryState = SecondaryState.NONE),
        button(_volHidden ? "Show Vol" : "Hide Vol",
            onPressed: () => _volHidden = !_volHidden),
        button("Change Language", onPressed: () => isChinese = !isChinese),
        button(_hideGrid ? "Show Grid" : "Hide Grid",
            onPressed: () => _hideGrid = !_hideGrid),
        button(_showNowPrice ? "Hide Now Price" : "Show Now Price",
            onPressed: () => _showNowPrice = !_showNowPrice),
        button("Customize UI", onPressed: () {
          setState(() {
            this.isChangeUI = !this.isChangeUI;
          });
        }),
        button("getData", onPressed: () {
          getData('1day');
        }),
      ],
    );
  }

  Widget button(String text, {VoidCallback onPressed}) {
    return TextButton(
      onPressed: () {
        if (onPressed != null) {
          onPressed();
          setState(() {});
        }
      },
      child: Text(text),
      style: TextButton.styleFrom(
        primary: Colors.white,
        minimumSize: const Size(88, 44),
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(2.0)),
        ),
        backgroundColor: Colors.blue,
      ),
    );
  }

  void getData(String period) {
    uniqueMark =  Random().nextDouble().toString();
    var parseJson = {
      "ch": "market.btcusdt.kline.1day",
      "status": "ok",
      "ts": 1633682856059,
      "data": [
        {
          "id": 1633622400,
          "open": 53910,
          "close": 55719.99,
          "low": 53410.35,
          "high": 56073,
          "amount": 9379.278673256296,
          "vol": 509935523.2157123,
          "count": 331014
        },
        {
          "id": 1633536000,
          "open": 54975.38,
          "close": 53910,
          "low": 53343.03,
          "high": 55757.69,
          "amount": 14226.834376104867,
          "vol": 776578015.8361366,
          "count": 562856
        },
        {
          "id": 1633449600,
          "open": 49790.77,
          "close": 54975.39,
          "low": 49649.99,
          "high": 55517.24,
          "amount": 27611.68472277404,
          "vol": 1446694520.4602842,
          "count": 836035
        },
        {
          "id": 1633363200,
          "open": 47755.25,
          "close": 49790.78,
          "low": 47698.83,
          "high": 50366.66,
          "amount": 17198.386874002925,
          "vol": 849161173.7064464,
          "count": 546805
        },
        {
          "id": 1633276800,
          "open": 47879.99,
          "close": 47755.25,
          "low": 46916.07,
          "high": 49243.4,
          "amount": 14850.300237394196,
          "vol": 712614929.9673463,
          "count": 472770
        },
        {
          "id": 1633190400,
          "open": 47829.45,
          "close": 47879.99,
          "low": 47089.63,
          "high": 48296.68,
          "amount": 8738.41854476055,
          "vol": 418023197.7831454,
          "count": 324419
        },
        {
          "id": 1633104000,
          "open": 47360.8,
          "close": 47829.46,
          "low": 47239.52,
          "high": 48464.45,
          "amount": 12438.377411711605,
          "vol": 594578605.1994928,
          "count": 400002
        },
        {
          "id": 1633017600,
          "open": 43149.38,
          "close": 47360.43,
          "low": 42824.9,
          "high": 47878,
          "amount": 27969.10891474815,
          "vol": 1271636419.512879,
          "count": 680868
        },
        {
          "id": 1632931200,
          "open": 41700.46,
          "close": 43149.37,
          "low": 40905.81,
          "high": 43834.63,
          "amount": 18519.77013076655,
          "vol": 792644816.553106,
          "count": 439487
        },
        {
          "id": 1632844800,
          "open": 41451.7,
          "close": 41700.46,
          "low": 40750,
          "high": 42588,
          "amount": 13139.717827401366,
          "vol": 549895755.4465437,
          "count": 386006
        },
        {
          "id": 1632758400,
          "open": 43290.42,
          "close": 41446.44,
          "low": 41276.65,
          "high": 43408.17,
          "amount": 15519.115237635586,
          "vol": 655969881.0156384,
          "count": 430426
        },
        {
          "id": 1632672000,
          "open": 43339.99,
          "close": 43284.53,
          "low": 42650,
          "high": 44351.82,
          "amount": 13594.96512024445,
          "vol": 592902661.994929,
          "count": 392804
        },
        {
          "id": 1632585600,
          "open": 42669.7,
          "close": 43340,
          "low": 40743.54,
          "high": 43926,
          "amount": 19441.32836716922,
          "vol": 824940847.928932,
          "count": 580952
        },
        {
          "id": 1632499200,
          "open": 41940.01,
          "close": 42669.7,
          "low": 41653.51,
          "high": 43207.65,
          "amount": 13220.846455428918,
          "vol": 561633405.1708008,
          "count": 458783
        },
        {
          "id": 1632412800,
          "open": 43752.04,
          "close": 41940.02,
          "low": 40663.16,
          "high": 45153.87,
          "amount": 27018.414774195047,
          "vol": 1164753889.5790124,
          "count": 816000
        },
        {
          "id": 1632326400,
          "open": 43219.05,
          "close": 43752.04,
          "low": 42852.92,
          "high": 44395.29,
          "amount": 14267.4837039445,
          "vol": 623113187.6439105,
          "count": 472578
        },
        {
          "id": 1632240000,
          "open": 43082.31,
          "close": 43219.05,
          "low": 39585.25,
          "high": 43295.09,
          "amount": 21737.542608974974,
          "vol": 906946012.2307129,
          "count": 727094
        },
        {
          "id": 1632153600,
          "open": 43850.68,
          "close": 43082.31,
          "low": 40150.93,
          "high": 44250,
          "amount": 22031.385489218264,
          "vol": 940262023.9856076,
          "count": 689202
        },
        {
          "id": 1632067200,
          "open": 47646.28,
          "close": 43850.67,
          "low": 42471.7,
          "high": 47822.88,
          "amount": 25108.423132991753,
          "vol": 1128214439.921753,
          "count": 744981
        },
        {
          "id": 1631980800,
          "open": 48413.64,
          "close": 47646.8,
          "low": 47051.35,
          "high": 48526.55,
          "amount": 9222.545768348644,
          "vol": 441434006.93917257,
          "count": 297368
        },
        {
          "id": 1631894400,
          "open": 47521.62,
          "close": 48413.64,
          "low": 46750,
          "high": 48825.08,
          "amount": 10919.487222838277,
          "vol": 523510392.75803185,
          "count": 339601
        },
        {
          "id": 1631808000,
          "open": 48017.69,
          "close": 47521.61,
          "low": 47035.17,
          "high": 48171.13,
          "amount": 11022.995217975124,
          "vol": 525354924.1758017,
          "count": 426687
        },
        {
          "id": 1631721600,
          "open": 48275.99,
          "close": 48017.4,
          "low": 47222,
          "high": 48497.66,
          "amount": 14341.340534991632,
          "vol": 688582919.7849381,
          "count": 454735
        },
        {
          "id": 1631635200,
          "open": 46749.39,
          "close": 48276,
          "low": 46328.33,
          "high": 48280.07,
          "amount": 14642.385907298636,
          "vol": 691723631.3527274,
          "count": 445034
        },
        {
          "id": 1631548800,
          "open": 44355.51,
          "close": 46749.4,
          "low": 44161.27,
          "high": 46944.44,
          "amount": 13604.060848715972,
          "vol": 619705918.169518,
          "count": 447491
        },
        {
          "id": 1631462400,
          "open": 45890.83,
          "close": 44355.52,
          "low": 43380,
          "high": 46854,
          "amount": 25254.002259137134,
          "vol": 1135450858.8761435,
          "count": 776513
        },
        {
          "id": 1631376000,
          "open": 45576,
          "close": 45890.82,
          "low": 44740.74,
          "high": 46250,
          "amount": 10377.907086377534,
          "vol": 472829045.5636531,
          "count": 337476
        },
        {
          "id": 1631289600,
          "open": 45420.71,
          "close": 45576,
          "low": 44134.95,
          "high": 45835.8,
          "amount": 13304.428221700035,
          "vol": 602044423.6084162,
          "count": 425076
        },
        {
          "id": 1631203200,
          "open": 46995.29,
          "close": 45419.97,
          "low": 44743.85,
          "high": 47385.93,
          "amount": 18602.669932373494,
          "vol": 857983725.517668,
          "count": 614020
        },
        {
          "id": 1631116800,
          "open": 46080,
          "close": 46995.29,
          "low": 45518,
          "high": 47229.39,
          "amount": 17388.141515921263,
          "vol": 805416417.5891337,
          "count": 584358
        },
        {
          "id": 1631030400,
          "open": 46652.86,
          "close": 46079.99,
          "low": 44417.62,
          "high": 47533.6,
          "amount": 30687.78916839595,
          "vol": 1421373168.3546429,
          "count": 985604
        },
        {
          "id": 1630944000,
          "open": 51601.86,
          "close": 46645.04,
          "low": 39818.18,
          "high": 52924.14,
          "amount": 46770.931554464245,
          "vol": 2291298312.620714,
          "count": 1373330
        },
        {
          "id": 1630857600,
          "open": 50211.16,
          "close": 51601.86,
          "low": 50120.14,
          "high": 52187.72,
          "amount": 14702.863020249368,
          "vol": 756203537.3849275,
          "count": 489117
        },
        {
          "id": 1630771200,
          "open": 49872.75,
          "close": 50211.16,
          "low": 49366,
          "high": 50500.06,
          "amount": 10823.762879155667,
          "vol": 541302747.7038426,
          "count": 386020
        },
        {
          "id": 1630684800,
          "open": 50552.7,
          "close": 49872.75,
          "low": 49571.43,
          "high": 50715.3,
          "amount": 10294.260713377062,
          "vol": 515775211.13077956,
          "count": 381255
        },
        {
          "id": 1630598400,
          "open": 49542,
          "close": 50552.69,
          "low": 48322.12,
          "high": 51000,
          "amount": 18434.551321708455,
          "vol": 917953401.984675,
          "count": 506544
        },
        {
          "id": 1630512000,
          "open": 47488.01,
          "close": 49542,
          "low": 47395.22,
          "high": 50346.97,
          "amount": 19297.856621117906,
          "vol": 951415857.100615,
          "count": 562704
        },
        {
          "id": 1630425600,
          "open": 47398.95,
          "close": 47488.01,
          "low": 46510.83,
          "high": 47835,
          "amount": 12899.35697335217,
          "vol": 609213616.3985018,
          "count": 402087
        },
        {
          "id": 1630339200,
          "open": 48024.01,
          "close": 47398.95,
          "low": 46700,
          "high": 48696.69,
          "amount": 16585.41703981737,
          "vol": 789129186.0898014,
          "count": 503036
        },
        {
          "id": 1630252800,
          "open": 48477.84,
          "close": 48024,
          "low": 47369.04,
          "high": 49381.81,
          "amount": 10753.081201087072,
          "vol": 518217819.33254623,
          "count": 369552
        },
        {
          "id": 1630166400,
          "open": 48809.37,
          "close": 48478.04,
          "low": 47756.95,
          "high": 49632.35,
          "amount": 10539.41764806354,
          "vol": 512948694.2248509,
          "count": 336394
        },
        {
          "id": 1630080000,
          "open": 48190.36,
          "close": 48809.36,
          "low": 47974.16,
          "high": 49280,
          "amount": 9202.770421881338,
          "vol": 448692464.816173,
          "count": 306679
        },
        {
          "id": 1629993600,
          "open": 46799.99,
          "close": 48191.36,
          "low": 46333.97,
          "high": 48423.96,
          "amount": 14689.220851151977,
          "vol": 694444569.2050412,
          "count": 457712
        },
        {
          "id": 1629907200,
          "open": 48811.26,
          "close": 46799.99,
          "low": 46288,
          "high": 49350,
          "amount": 18368.943022276184,
          "vol": 875133063.5393312,
          "count": 572096
        },
        {
          "id": 1629820800,
          "open": 48315.68,
          "close": 48811.27,
          "low": 47128,
          "high": 48849.73,
          "amount": 14862.88143830038,
          "vol": 713262023.3058087,
          "count": 495464
        },
        {
          "id": 1629734400,
          "open": 49527.05,
          "close": 48315.69,
          "low": 48211.72,
          "high": 49862,
          "amount": 13021.279944247375,
          "vol": 640427308.175554,
          "count": 443759
        },
        {
          "id": 1629648000,
          "open": 48527.89,
          "close": 49527.04,
          "low": 48174.63,
          "high": 50500,
          "amount": 16505.811080390256,
          "vol": 819641379.565855,
          "count": 508891
        },
        {
          "id": 1629561600,
          "open": 49181.01,
          "close": 48527.89,
          "low": 48021.1,
          "high": 49780,
          "amount": 10936.299980174283,
          "vol": 535756850.7763685,
          "count": 384609
        },
        {
          "id": 1629475200,
          "open": 48716.99,
          "close": 49181,
          "low": 48229.6,
          "high": 49432,
          "amount": 13339.038003116873,
          "vol": 651874030.4353238,
          "count": 465269
        },
        {
          "id": 1629388800,
          "open": 45779.61,
          "close": 48717,
          "low": 45406.03,
          "high": 48717,
          "amount": 18388.532655515606,
          "vol": 866305098.987464,
          "count": 556234
        },
        {
          "id": 1629302400,
          "open": 45824.03,
          "close": 45779.61,
          "low": 43913.34,
          "high": 46021.44,
          "amount": 17170.794480731623,
          "vol": 770075913.4159402,
          "count": 535246
        },
        {
          "id": 1629216000,
          "open": 45726.97,
          "close": 45824.03,
          "low": 44215.21,
          "high": 46196.28,
          "amount": 20822.918511491513,
          "vol": 939016531.024026,
          "count": 690046
        },
        {
          "id": 1629129600,
          "open": 46335.49,
          "close": 45726.98,
          "low": 45247.7,
          "high": 47172.4,
          "amount": 16975.04099963892,
          "vol": 784545351.3196003,
          "count": 570376
        },
        {
          "id": 1629043200,
          "open": 46168.31,
          "close": 46335.5,
          "low": 45642.85,
          "high": 48050,
          "amount": 17758.256903981637,
          "vol": 834536857.426092,
          "count": 560144
        },
        {
          "id": 1628956800,
          "open": 46932.31,
          "close": 46168.31,
          "low": 45477.01,
          "high": 47380,
          "amount": 14855.82640050098,
          "vol": 689259401.809534,
          "count": 469810
        },
        {
          "id": 1628870400,
          "open": 46363.21,
          "close": 46932.31,
          "low": 46000,
          "high": 48147.48,
          "amount": 16398.70892889381,
          "vol": 772024277.8012446,
          "count": 537809
        },
        {
          "id": 1628784000,
          "open": 44193.76,
          "close": 46363.2,
          "low": 43776.34,
          "high": 46666,
          "amount": 16146.613640933425,
          "vol": 732394434.189514,
          "count": 557982
        },
        {
          "id": 1628697600,
          "open": 46447.42,
          "close": 44193.11,
          "low": 43918.36,
          "high": 46679.32,
          "amount": 16659.060527915582,
          "vol": 754662271.4694415,
          "count": 585150
        },
        {
          "id": 1628611200,
          "open": 45158.14,
          "close": 46447.42,
          "low": 44642.85,
          "high": 46739.35,
          "amount": 13631.03067247437,
          "vol": 625014146.1710585,
          "count": 506108
        },
        {
          "id": 1628524800,
          "open": 45868.38,
          "close": 45158.14,
          "low": 44850,
          "high": 46711,
          "amount": 20779.525550449773,
          "vol": 950301182.6671721,
          "count": 621893
        },
        {
          "id": 1628438400,
          "open": 43990.76,
          "close": 45868.38,
          "low": 42780,
          "high": 46284.69,
          "amount": 22831.8815429405,
          "vol": 1013754769.0586847,
          "count": 675079
        },
        {
          "id": 1628352000,
          "open": 43368.37,
          "close": 43990.75,
          "low": 42446.09,
          "high": 45324.44,
          "amount": 21827.091971200905,
          "vol": 964904359.7603585,
          "count": 696459
        },
        {
          "id": 1628265600,
          "open": 42200.33,
          "close": 43368.37,
          "low": 42199.87,
          "high": 44557.62,
          "amount": 23930.274125298594,
          "vol": 1034113421.2707269,
          "count": 724300
        },
        {
          "id": 1628179200,
          "open": 38754.01,
          "close": 42200.34,
          "low": 38698.74,
          "high": 42451,
          "amount": 22677.278629289107,
          "vol": 923185397.66901,
          "count": 713817
        },
        {
          "id": 1628092800,
          "open": 39303.99,
          "close": 38754.01,
          "low": 37305.38,
          "high": 39965.51,
          "amount": 15915.316323357052,
          "vol": 616828305.0779375,
          "count": 517431
        },
        {
          "id": 1628006400,
          "open": 38174.82,
          "close": 39304,
          "low": 37500,
          "high": 39460,
          "amount": 13707.562869505635,
          "vol": 525362469.07091177,
          "count": 413794
        },
        {
          "id": 1627920000,
          "open": 39698.64,
          "close": 38174.82,
          "low": 37698.08,
          "high": 39971.54,
          "amount": 16334.737877297992,
          "vol": 632794853.0014366,
          "count": 449297
        },
        {
          "id": 1627833600,
          "open": 41289.3,
          "close": 39697.99,
          "low": 38894.23,
          "high": 41500,
          "amount": 17898.489515515193,
          "vol": 717333062.6718633,
          "count": 535016
        },
        {
          "id": 1627747200,
          "open": 41540.32,
          "close": 41289.3,
          "low": 41034.71,
          "high": 42585,
          "amount": 13537.195478207965,
          "vol": 564316642.637183,
          "count": 396837
        },
        {
          "id": 1627660800,
          "open": 39071.5,
          "close": 41540.32,
          "low": 38872.24,
          "high": 42400,
          "amount": 19192.758306199103,
          "vol": 791491450.7221043,
          "count": 604822
        },
        {
          "id": 1627574400,
          "open": 39948.12,
          "close": 39071.5,
          "low": 38327,
          "high": 40408.92,
          "amount": 14019.249820368848,
          "vol": 552342423.120996,
          "count": 449890
        },
        {
          "id": 1627488000,
          "open": 39685.9,
          "close": 39948.12,
          "low": 38777.85,
          "high": 40674.62,
          "amount": 19583.032737360096,
          "vol": 780825752.6824899,
          "count": 553549
        },
        {
          "id": 1627401600,
          "open": 38211.01,
          "close": 39685.9,
          "low": 37356.64,
          "high": 40888,
          "amount": 26291.846834601263,
          "vol": 1038723321.6535711,
          "count": 723013
        },
        {
          "id": 1627315200,
          "open": 38561.51,
          "close": 38211.02,
          "low": 36387.69,
          "high": 40547.06,
          "amount": 35390.39342297819,
          "vol": 1346693985.9078598,
          "count": 940656
        },
        {
          "id": 1627228800,
          "open": 34175.87,
          "close": 38562.69,
          "low": 34087.43,
          "high": 39799.11,
          "amount": 36460.26762041634,
          "vol": 1371344485.67848,
          "count": 912373
        },
        {
          "id": 1627142400,
          "open": 33852.41,
          "close": 34175.87,
          "low": 33674.06,
          "high": 34797.9,
          "amount": 12529.474995685388,
          "vol": 429326923.48834276,
          "count": 377246
        },
        {
          "id": 1627056000,
          "open": 32316.53,
          "close": 33852.41,
          "low": 31980.93,
          "high": 34050.19,
          "amount": 14422.89388251673,
          "vol": 480471689.62117195,
          "count": 376286
        },
        {
          "id": 1626969600,
          "open": 32495.42,
          "close": 32311.08,
          "low": 32057.3,
          "high": 32941.59,
          "amount": 8240.06021960894,
          "vol": 267513936.50655314,
          "count": 274735
        },
        {
          "id": 1626883200,
          "open": 31933.65,
          "close": 32498.6,
          "low": 31518.44,
          "high": 32806.05,
          "amount": 17936.909907262983,
          "vol": 575596782.7780697,
          "count": 486125
        },
        {
          "id": 1626796800,
          "open": 29888.01,
          "close": 31929.19,
          "low": 29490.8,
          "high": 31964.28,
          "amount": 17989.2264015816,
          "vol": 553195602.043487,
          "count": 398512
        },
        {
          "id": 1626710400,
          "open": 30688.27,
          "close": 29889.95,
          "low": 29278.45,
          "high": 31059.11,
          "amount": 18683.832718353267,
          "vol": 560437973.8492709,
          "count": 424934
        },
        {
          "id": 1626624000,
          "open": 31362.35,
          "close": 30688.27,
          "low": 30402.23,
          "high": 31942.37,
          "amount": 14329.75093021862,
          "vol": 447356834.59373564,
          "count": 350949
        },
        {
          "id": 1626537600,
          "open": 31758.54,
          "close": 31366.69,
          "low": 31100,
          "high": 32442.54,
          "amount": 12181.668729690846,
          "vol": 387318453.4075529,
          "count": 295050
        },
        {
          "id": 1626451200,
          "open": 32133.21,
          "close": 31758.53,
          "low": 31165.18,
          "high": 32244.86,
          "amount": 10484.408416385026,
          "vol": 331366428.3099112,
          "count": 329415
        },
        {
          "id": 1626364800,
          "open": 31680.98,
          "close": 32133.21,
          "low": 31022.46,
          "high": 32198,
          "amount": 12089.859721091945,
          "vol": 382448773.58357775,
          "count": 388410
        },
        {
          "id": 1626278400,
          "open": 32784.01,
          "close": 31680.97,
          "low": 31460.36,
          "high": 33186.11,
          "amount": 11962.498569824751,
          "vol": 386655011.67461884,
          "count": 372943
        },
        {
          "id": 1626192000,
          "open": 32791.8,
          "close": 32784,
          "low": 31580,
          "high": 32961.53,
          "amount": 13477.845000000158,
          "vol": 435519743.56128615,
          "count": 412997
        },
        {
          "id": 1626105600,
          "open": 33339.02,
          "close": 32789.67,
          "low": 32285.42,
          "high": 33441.64,
          "amount": 14681.192488754594,
          "vol": 483549510.00903875,
          "count": 397899
        },
        {
          "id": 1626019200,
          "open": 33949.99,
          "close": 33339.57,
          "low": 33315.93,
          "high": 34678.92,
          "amount": 12916.849504142709,
          "vol": 440399329.62248653,
          "count": 337065
        },
        {
          "id": 1625932800,
          "open": 33863.4,
          "close": 33950,
          "low": 33035,
          "high": 34195.9,
          "amount": 8064.934772734467,
          "vol": 271209370.1716872,
          "count": 269593
        },
        {
          "id": 1625846400,
          "open": 33556.3,
          "close": 33863.4,
          "low": 33285.55,
          "high": 34262.23,
          "amount": 9293.715545416573,
          "vol": 313866623.8006653,
          "count": 301945
        },
        {
          "id": 1625760000,
          "open": 32899.92,
          "close": 33560,
          "low": 32271.11,
          "high": 33684.21,
          "amount": 14469.8301972679,
          "vol": 476926759.72578466,
          "count": 409855
        },
        {
          "id": 1625673600,
          "open": 34533.41,
          "close": 32899.93,
          "low": 32099.99,
          "high": 34785.9,
          "amount": 18378.63523737311,
          "vol": 608912237.4461281,
          "count": 519502
        },
        {
          "id": 1625587200,
          "open": 34046.22,
          "close": 34533.41,
          "low": 33518.58,
          "high": 35057.72,
          "amount": 14282.034821975067,
          "vol": 491802156.21849674,
          "count": 407699
        },
        {
          "id": 1625500800,
          "open": 33585.67,
          "close": 34038.99,
          "low": 33128.99,
          "high": 35114.62,
          "amount": 19722.38280792227,
          "vol": 673877301.1373438,
          "count": 506798
        },
        {
          "id": 1625414400,
          "open": 35514.02,
          "close": 33585.66,
          "low": 33302.54,
          "high": 35959.59,
          "amount": 19683.442191660044,
          "vol": 677007493.4214553,
          "count": 459771
        },
        {
          "id": 1625328000,
          "open": 34608.61,
          "close": 35512.22,
          "low": 34272,
          "high": 35699,
          "amount": 13913.859148375474,
          "vol": 487254238.00043,
          "count": 340084
        },
        {
          "id": 1625241600,
          "open": 33700,
          "close": 34608.61,
          "low": 33043.62,
          "high": 34807.69,
          "amount": 12847.256648246119,
          "vol": 437378051.4803982,
          "count": 334613
        },
        {
          "id": 1625155200,
          "open": 33430.75,
          "close": 33699.99,
          "low": 32700,
          "high": 33979.86,
          "amount": 18418.718318370487,
          "vol": 612763953.4781746,
          "count": 489106
        },
        {
          "id": 1625068800,
          "open": 34195.5,
          "close": 33430.74,
          "low": 33001,
          "high": 35200,
          "amount": 24419.728259613985,
          "vol": 830178338.1657823,
          "count": 588978
        },
        {
          "id": 1624982400,
          "open": 36253.16,
          "close": 34198.93,
          "low": 34080,
          "high": 36603.45,
          "amount": 23290.859030911222,
          "vol": 823165068.5829107,
          "count": 614362
        },
        {
          "id": 1624896000,
          "open": 34965.09,
          "close": 36253.16,
          "low": 33968.13,
          "high": 36432.04,
          "amount": 27765.54502296667,
          "vol": 975437654.3915536,
          "count": 719605
        },
        {
          "id": 1624809600,
          "open": 33198.74,
          "close": 34965.07,
          "low": 32403.54,
          "high": 35298.08,
          "amount": 29726.730232552098,
          "vol": 1016309085.4973856,
          "count": 746117
        },
        {
          "id": 1624723200,
          "open": 31527.65,
          "close": 33198.74,
          "low": 30779.89,
          "high": 33572.67,
          "amount": 30357.608915948716,
          "vol": 988774201.8018011,
          "count": 742836
        },
        {
          "id": 1624636800,
          "open": 32607.14,
          "close": 31527.65,
          "low": 30150,
          "high": 32905.79,
          "amount": 47014.23742575875,
          "vol": 1480421191.9528074,
          "count": 1068654
        },
        {
          "id": 1624550400,
          "open": 33886.91,
          "close": 32606.74,
          "low": 32350,
          "high": 35500,
          "amount": 38129.33668961228,
          "vol": 1297323191.6448765,
          "count": 1108800
        },
        {
          "id": 1624464000,
          "open": 33493.07,
          "close": 33886.92,
          "low": 32309.21,
          "high": 34578.99,
          "amount": 29123.757840348633,
          "vol": 970981639.3146747,
          "count": 839487
        },
        {
          "id": 1624377600,
          "open": 31687.65,
          "close": 33496.84,
          "low": 31614.09,
          "high": 34829.54,
          "amount": 47491.48395410613,
          "vol": 1586115511.5228696,
          "count": 1209151
        },
        {
          "id": 1624291200,
          "open": 32685.94,
          "close": 31687.5,
          "low": 28800,
          "high": 33258,
          "amount": 70294.78005495448,
          "vol": 2193283792.6030593,
          "count": 1806178
        },
        {
          "id": 1624204800,
          "open": 34417.59,
          "close": 32690,
          "low": 31700,
          "high": 36147.05,
          "amount": 54399.039666932455,
          "vol": 1816737914.1471417,
          "count": 1403306
        },
        {
          "id": 1624118400,
          "open": 36113.42,
          "close": 34417.99,
          "low": 33336.07,
          "high": 36206.46,
          "amount": 29290.436266112403,
          "vol": 1020577199.9027603,
          "count": 723121
        },
        {
          "id": 1624032000,
          "open": 36354.17,
          "close": 36113.42,
          "low": 34800,
          "high": 36700,
          "amount": 27750.074480908694,
          "vol": 992226763.7113107,
          "count": 694828
        },
        {
          "id": 1623945600,
          "open": 39008.32,
          "close": 36353,
          "low": 36299.99,
          "high": 39114,
          "amount": 33756.45325134086,
          "vol": 1268259058.1090434,
          "count": 749635
        },
        {
          "id": 1623859200,
          "open": 38776.42,
          "close": 39008.31,
          "low": 38107,
          "high": 39707.4,
          "amount": 29150.361281909874,
          "vol": 1133239011.4647248,
          "count": 657986
        },
        {
          "id": 1623772800,
          "open": 40062.63,
          "close": 38777.26,
          "low": 38568,
          "high": 41328,
          "amount": 27867.774397299545,
          "vol": 1112059791.922645,
          "count": 665050
        },
        {
          "id": 1623686400,
          "open": 40688.54,
          "close": 40060.86,
          "low": 39337.3,
          "high": 41000,
          "amount": 26651.236649396356,
          "vol": 1069995764.4320964,
          "count": 654898
        },
        {
          "id": 1623600000,
          "open": 36036.05,
          "close": 40688.55,
          "low": 35969.27,
          "high": 41000,
          "amount": 45347.97873956564,
          "vol": 1770089570.409876,
          "count": 1029292
        },
        {
          "id": 1623513600,
          "open": 35396.3,
          "close": 36036.06,
          "low": 34761.54,
          "high": 36155.17,
          "amount": 19244.28162474243,
          "vol": 684861591.1778022,
          "count": 509178
        },
        {
          "id": 1623427200,
          "open": 36821.26,
          "close": 35396.31,
          "low": 34608.05,
          "high": 37498.38,
          "amount": 29319.943030496797,
          "vol": 1057064855.0467175,
          "count": 830968
        },
        {
          "id": 1623340800,
          "open": 36902.49,
          "close": 36826.6,
          "low": 35801,
          "high": 37680,
          "amount": 28429.106120182947,
          "vol": 1047830217.1530126,
          "count": 849456
        },
        {
          "id": 1623254400,
          "open": 36361.3,
          "close": 36902.48,
          "low": 35648.09,
          "high": 38460,
          "amount": 42250.224990879644,
          "vol": 1565162442.2881649,
          "count": 1048790
        },
        {
          "id": 1623168000,
          "open": 31703.72,
          "close": 36359.49,
          "low": 31500,
          "high": 36708.62,
          "amount": 44767.671605443,
          "vol": 1527420975.8413172,
          "count": 1202567
        },
        {
          "id": 1623081600,
          "open": 36035.42,
          "close": 31703.75,
          "low": 31000,
          "high": 36083.18,
          "amount": 42656.836201206024,
          "vol": 1417808960.8950737,
          "count": 1288066
        },
        {
          "id": 1622995200,
          "open": 36160.8,
          "close": 36035.42,
          "low": 35222,
          "high": 36806.35,
          "amount": 20017.687255741545,
          "vol": 724290293.5374913,
          "count": 591329
        },
        {
          "id": 1622908800,
          "open": 36320.71,
          "close": 36160.81,
          "low": 34810.12,
          "high": 36468.08,
          "amount": 19880.205437403074,
          "vol": 712488197.6734048,
          "count": 631538
        },
        {
          "id": 1622822400,
          "open": 36942.56,
          "close": 36320.71,
          "low": 35240.68,
          "high": 37900,
          "amount": 27385.976871938405,
          "vol": 1006332729.6588461,
          "count": 799319
        },
        {
          "id": 1622736000,
          "open": 38533.62,
          "close": 36949.73,
          "low": 35565,
          "high": 39280,
          "amount": 32206.07019286008,
          "vol": 1201355996.0002227,
          "count": 983487
        },
        {
          "id": 1622649600,
          "open": 38039.81,
          "close": 38533.61,
          "low": 37175,
          "high": 39475.3,
          "amount": 24486.102561132524,
          "vol": 938574548.149515,
          "count": 767805
        },
        {
          "id": 1622563200,
          "open": 36229.32,
          "close": 38039.81,
          "low": 35718.81,
          "high": 38225.09,
          "amount": 25858.918048274056,
          "vol": 953724858.9725087,
          "count": 816421
        },
        {
          "id": 1622476800,
          "open": 36961.31,
          "close": 36229.33,
          "low": 35690.05,
          "high": 37892.94,
          "amount": 31674.97556285697,
          "vol": 1165303336.176297,
          "count": 920154
        },
        {
          "id": 1622390400,
          "open": 35474.65,
          "close": 36961.31,
          "low": 34149.63,
          "high": 37279,
          "amount": 29780.813324120423,
          "vol": 1067666754.0487161,
          "count": 940402
        },
        {
          "id": 1622304000,
          "open": 34419.9,
          "close": 35474.65,
          "low": 33380.01,
          "high": 36493.72,
          "amount": 32184.09864183019,
          "vol": 1122048038.336864,
          "count": 1065813
        },
        {
          "id": 1622217600,
          "open": 36754,
          "close": 34418.2,
          "low": 33819.45,
          "high": 37324.99,
          "amount": 42099.242611726186,
          "vol": 1496986499.0703866,
          "count": 1390411
        },
        {
          "id": 1622131200,
          "open": 39672,
          "close": 36753.99,
          "low": 35100,
          "high": 39736.88,
          "amount": 40424.564699304276,
          "vol": 1503513628.1869273,
          "count": 1426196
        },
        {
          "id": 1622044800,
          "open": 38756.27,
          "close": 39672,
          "low": 37134.56,
          "high": 40416.99,
          "amount": 37151.48703481143,
          "vol": 1439988058.0870392,
          "count": 1269685
        },
        {
          "id": 1621958400,
          "open": 38266.61,
          "close": 38756.27,
          "low": 37125.4,
          "high": 40846.08,
          "amount": 39233.30212475475,
          "vol": 1535642806.1449995,
          "count": 1499301
        },
        {
          "id": 1621872000,
          "open": 37546.32,
          "close": 38266.61,
          "low": 36429.56,
          "high": 39913,
          "amount": 53639.58179228346,
          "vol": 2048064011.0735126,
          "count": 2082816
        },
        {
          "id": 1621785600,
          "open": 33326.35,
          "close": 37540.82,
          "low": 31111,
          "high": 38691,
          "amount": 74171.9836565061,
          "vol": 2599959922.974859,
          "count": 2706307
        },
        {
          "id": 1621699200,
          "open": 38164.75,
          "close": 33326.35,
          "low": 32615.02,
          "high": 38554.3,
          "amount": 65957.16725171731,
          "vol": 2338778793.5796533,
          "count": 2320896
        },
        {
          "id": 1621612800,
          "open": 36787.81,
          "close": 38159.91,
          "low": 33500,
          "high": 38839.89,
          "amount": 75076.30617875121,
          "vol": 2761842736.922634,
          "count": 2674532
        },
        {
          "id": 1621526400,
          "open": 41440,
          "close": 36790.55,
          "low": 36409.14,
          "high": 42244.89,
          "amount": 80692.7082895884,
          "vol": 3183371400.6659656,
          "count": 2875694
        },
        {
          "id": 1621440000,
          "open": 37270.46,
          "close": 41437.48,
          "low": 34912.28,
          "high": 42425.51,
          "amount": 98346.36876154601,
          "vol": 3829262273.4575944,
          "count": 3942355
        },
        {
          "id": 1621353600,
          "open": 42974.66,
          "close": 37270.46,
          "low": 29000.59,
          "high": 43820.05,
          "amount": 152337.45633991782,
          "vol": 5762387098.769387,
          "count": 4975924
        },
        {
          "id": 1621267200,
          "open": 43342.5,
          "close": 42971.15,
          "low": 42106,
          "high": 45781.52,
          "amount": 51355.99110085255,
          "vol": 2259884496.9773135,
          "count": 1923309
        },
        {
          "id": 1621180800,
          "open": 47738.24,
          "close": 43342.5,
          "low": 42118,
          "high": 48098.66,
          "amount": 74916.51770939043,
          "vol": 3353661606.1641746,
          "count": 2812352
        },
        {
          "id": 1621094400,
          "open": 48983.62,
          "close": 47738.24,
          "low": 46500,
          "high": 49800,
          "amount": 27682.228473043888,
          "vol": 1333333213.8079085,
          "count": 1365495
        },
        {
          "id": 1621008000,
          "open": 51216.11,
          "close": 48975.69,
          "low": 47780,
          "high": 51350.66,
          "amount": 26439.814838040264,
          "vol": 1307177680.3637547,
          "count": 1369598
        },
        {
          "id": 1620921600,
          "open": 49636.3,
          "close": 51216.11,
          "low": 47000,
          "high": 51459.25,
          "amount": 40371.75404613826,
          "vol": 1996558144.4153147,
          "count": 1760970
        },
        {
          "id": 1620835200,
          "open": 55476.89,
          "close": 49636.31,
          "low": 45500,
          "high": 55666.66,
          "amount": 104394.51052384336,
          "vol": 5264729508.241486,
          "count": 3284913
        },
        {
          "id": 1620748800,
          "open": 56047.34,
          "close": 55476.88,
          "low": 55247.17,
          "high": 57988,
          "amount": 23732.932849303546,
          "vol": 1343148054.1036391,
          "count": 1378731
        },
        {
          "id": 1620662400,
          "open": 58287.1,
          "close": 56047.33,
          "low": 53528.28,
          "high": 58558.84,
          "amount": 40003.69584671746,
          "vol": 2228655806.096215,
          "count": 2028258
        },
        {
          "id": 1620576000,
          "open": 57377.81,
          "close": 58287.1,
          "low": 56612.02,
          "high": 59522,
          "amount": 27320.078645299796,
          "vol": 1588004992.5701754,
          "count": 1239454
        },
        {
          "id": 1620489600,
          "open": 57584.55,
          "close": 57369.16,
          "low": 56210.32,
          "high": 59488,
          "amount": 33006.23636199477,
          "vol": 1920593030.6823578,
          "count": 1430122
        },
        {
          "id": 1620403200,
          "open": 57516.53,
          "close": 57584.55,
          "low": 56750,
          "high": 59426.86,
          "amount": 30397.926339223235,
          "vol": 1768265630.4575777,
          "count": 1441603
        },
        {
          "id": 1620316800,
          "open": 57087.43,
          "close": 57516.52,
          "low": 55233.78,
          "high": 57685.87,
          "amount": 28974.093676766126,
          "vol": 1632158119.8419178,
          "count": 1721592
        },
        {
          "id": 1620230400,
          "open": 57629.56,
          "close": 57087.43,
          "low": 56361.71,
          "high": 58370.36,
          "amount": 26218.368312119408,
          "vol": 1502665225.017099,
          "count": 1337528
        },
        {
          "id": 1620144000,
          "open": 53803.96,
          "close": 57629.56,
          "low": 52888,
          "high": 57700,
          "amount": 30423.247724456978,
          "vol": 1671300686.7986495,
          "count": 1410987
        },
        {
          "id": 1620057600,
          "open": 57592.47,
          "close": 53803.41,
          "low": 53550,
          "high": 58175,
          "amount": 33502.5710134813,
          "vol": 1873579278.174381,
          "count": 1434552
        },
        {
          "id": 1619971200,
          "open": 56601.09,
          "close": 57592.47,
          "low": 56228,
          "high": 59000.12,
          "amount": 18157.469795980483,
          "vol": 1050217581.3739812,
          "count": 813292
        },
        {
          "id": 1619884800,
          "open": 57366.31,
          "close": 56601.1,
          "low": 56058.82,
          "high": 57999.88,
          "amount": 14230.762133301256,
          "vol": 811694009.4065139,
          "count": 770320
        },
        {
          "id": 1619798400,
          "open": 57148.7,
          "close": 57366.32,
          "low": 56284.46,
          "high": 58463.25,
          "amount": 18545.587866884547,
          "vol": 1065776626.2371552,
          "count": 908128
        },
        {
          "id": 1619712000,
          "open": 53709.7,
          "close": 57142.08,
          "low": 52336.36,
          "high": 57236.52,
          "amount": 24782.10405838494,
          "vol": 1346177798.3020701,
          "count": 1063534
        },
        {
          "id": 1619625600,
          "open": 54341.06,
          "close": 53709.7,
          "low": 53316.99,
          "high": 56424.09,
          "amount": 22198.947791087277,
          "vol": 1208932493.0049312,
          "count": 893168
        },
        {
          "id": 1619539200,
          "open": 54975.56,
          "close": 54339,
          "low": 53807.34,
          "high": 55733,
          "amount": 22196.15864168224,
          "vol": 1216793480.1932418,
          "count": 883929
        },
        {
          "id": 1619452800,
          "open": 53569.07,
          "close": 54975.55,
          "low": 52617.64,
          "high": 55310,
          "amount": 28121.226599506062,
          "vol": 1521762420.1065998,
          "count": 972113
        },
        {
          "id": 1619366400,
          "open": 50254.07,
          "close": 53569.07,
          "low": 47000,
          "high": 53938.32,
          "amount": 41356.24800259509,
          "vol": 2120438422.7589755,
          "count": 1261536
        },
        {
          "id": 1619280000,
          "open": 50207.93,
          "close": 50254.07,
          "low": 49092.2,
          "high": 50992.47,
          "amount": 21454.563581077997,
          "vol": 1072158287.5851175,
          "count": 823444
        },
        {
          "id": 1619193600,
          "open": 49825.59,
          "close": 50207.93,
          "low": 48673.1,
          "high": 51265.33,
          "amount": 26904.807508231843,
          "vol": 1343430181.1946447,
          "count": 1089069
        },
        {
          "id": 1619107200,
          "open": 54649.99,
          "close": 49845.51,
          "low": 47520,
          "high": 55170.23,
          "amount": 75320.234848096,
          "vol": 3793548429.518338,
          "count": 2627994
        },
        {
          "id": 1619020800,
          "open": 56153.34,
          "close": 54648.14,
          "low": 52577.19,
          "high": 56332.98,
          "amount": 32206.945554397877,
          "vol": 1748039698.142488,
          "count": 1300291
        },
        {
          "id": 1618934400,
          "open": 55331.56,
          "close": 56153.33,
          "low": 54200,
          "high": 57060.15,
          "amount": 26084.916188413525,
          "vol": 1453983900.0112529,
          "count": 1075354
        },
        {
          "id": 1618848000,
          "open": 54577.14,
          "close": 55322.47,
          "low": 53341.27,
          "high": 56605.67,
          "amount": 36193.6465675508,
          "vol": 1992618846.641596,
          "count": 1479139
        },
        {
          "id": 1618761600,
          "open": 55450.58,
          "close": 54577.14,
          "low": 54222.92,
          "high": 57525.9,
          "amount": 30453.77353725106,
          "vol": 1711972570.2357838,
          "count": 1427202
        },
        {
          "id": 1618675200,
          "open": 60267.12,
          "close": 55454.74,
          "low": 50880,
          "high": 60945.52,
          "amount": 80786.41432322306,
          "vol": 4496280960.744457,
          "count": 2697968
        },
        {
          "id": 1618588800,
          "open": 61500.01,
          "close": 60267.39,
          "low": 60088.92,
          "high": 62499,
          "amount": 24392.105045378816,
          "vol": 1500165515.9909067,
          "count": 1482526
        },
        {
          "id": 1618502400,
          "open": 62708.49,
          "close": 61500.02,
          "low": 60003,
          "high": 63768.31,
          "amount": 30911.71497426226,
          "vol": 1908742507.6494913,
          "count": 1517483
        },
        {
          "id": 1618416000,
          "open": 63045,
          "close": 62708.5,
          "low": 61308,
          "high": 63754.21,
          "amount": 21288.23369797482,
          "vol": 1333986111.7295215,
          "count": 1058317
        },
        {
          "id": 1618329600,
          "open": 63317.48,
          "close": 63045,
          "low": 62361.21,
          "high": 64843.03,
          "amount": 28653.748433272573,
          "vol": 1822201474.7619705,
          "count": 1417823
        },
        {
          "id": 1618243200,
          "open": 59987.27,
          "close": 63317.47,
          "low": 59679.03,
          "high": 63655,
          "amount": 23344.27261641228,
          "vol": 1436563350.2886386,
          "count": 1261794
        },
        {
          "id": 1618156800,
          "open": 59654.25,
          "close": 59987.24,
          "low": 59402.96,
          "high": 61200,
          "amount": 17922.25602756229,
          "vol": 1078039634.1126258,
          "count": 987884
        },
        {
          "id": 1618070400,
          "open": 60254.95,
          "close": 59654.25,
          "low": 58369.23,
          "high": 60699,
          "amount": 14531.992422674177,
          "vol": 867757351.0934098,
          "count": 904449
        },
        {
          "id": 1617984000,
          "open": 58238.53,
          "close": 60254.94,
          "low": 57860.32,
          "high": 61400,
          "amount": 22885.40228227196,
          "vol": 1369878062.4669733,
          "count": 1023430
        },
        {
          "id": 1617897600,
          "open": 57770.74,
          "close": 58238.53,
          "low": 57455.9,
          "high": 58933.75,
          "amount": 15353.790754890582,
          "vol": 893128484.0955842,
          "count": 781047
        },
        {
          "id": 1617811200,
          "open": 56461.66,
          "close": 57770.73,
          "low": 55475.74,
          "high": 57913.34,
          "amount": 19537.047314615702,
          "vol": 1107983898.9036562,
          "count": 1041530
        },
        {
          "id": 1617724800,
          "open": 57819.58,
          "close": 56461.67,
          "low": 55616.1,
          "high": 58700.04,
          "amount": 27175.760219088665,
          "vol": 1557917822.7819076,
          "count": 1558531
        },
        {
          "id": 1617638400,
          "open": 59016.29,
          "close": 57819.58,
          "low": 57401,
          "high": 59500,
          "amount": 19366.85238321185,
          "vol": 1134927807.6176882,
          "count": 1269137
        },
        {
          "id": 1617552000,
          "open": 57915.91,
          "close": 59016.29,
          "low": 56766.84,
          "high": 59268,
          "amount": 15266.633901090061,
          "vol": 883518874.5763651,
          "count": 912901
        },
        {
          "id": 1617465600,
          "open": 58824.28,
          "close": 57915.9,
          "low": 56368.42,
          "high": 59146.05,
          "amount": 18656.425492471204,
          "vol": 1076595479.6124372,
          "count": 1032367
        },
        {
          "id": 1617379200,
          "open": 59488.5,
          "close": 58824.28,
          "low": 58466.29,
          "high": 59792.14,
          "amount": 12869.652021401333,
          "vol": 761695898.3976785,
          "count": 767475
        },
        {
          "id": 1617292800,
          "open": 58977.87,
          "close": 59495.98,
          "low": 57935.04,
          "high": 60169.85,
          "amount": 19011.81482092354,
          "vol": 1125941903.7260003,
          "count": 956682
        },
        {
          "id": 1617206400,
          "open": 59302.18,
          "close": 58977.87,
          "low": 58122.33,
          "high": 59650,
          "amount": 18605.6188050102,
          "vol": 1096328646.1607656,
          "count": 944664
        },
        {
          "id": 1617120000,
          "open": 58537.36,
          "close": 59295.62,
          "low": 56802,
          "high": 59774.1,
          "amount": 23040.10582792383,
          "vol": 1346555673.9267757,
          "count": 1042571
        },
        {
          "id": 1617033600,
          "open": 57717.11,
          "close": 58537.35,
          "low": 57077.41,
          "high": 59350,
          "amount": 20565.08113630961,
          "vol": 1195447976.169496,
          "count": 902876
        },
        {
          "id": 1616947200,
          "open": 56366.08,
          "close": 57716.62,
          "low": 54701,
          "high": 58370.46,
          "amount": 25694.919489716947,
          "vol": 1455066668.1071205,
          "count": 1052113
        },
        {
          "id": 1616860800,
          "open": 54955.22,
          "close": 56360.02,
          "low": 54955.22,
          "high": 56625.22,
          "amount": 19124.24496750536,
          "vol": 1069896003.582584,
          "count": 816022
        },
        {
          "id": 1616774400,
          "open": 53305.98,
          "close": 54956.58,
          "low": 52901,
          "high": 55538.76,
          "amount": 20529.359944680637,
          "vol": 1118718103.1618655,
          "count": 849780
        },
        {
          "id": 1616688000,
          "open": 50988.9,
          "close": 53305.98,
          "low": 50533.01,
          "high": 53813,
          "amount": 28066.630545918553,
          "vol": 1471677605.0360568,
          "count": 1226331
        },
        {
          "id": 1616601600,
          "open": 56301.45,
          "close": 50988.85,
          "low": 50465,
          "high": 56440.73,
          "amount": 42668.58971145991,
          "vol": 2243780214.0839486,
          "count": 1904962
        },
        {
          "id": 1616515200,
          "open": 55169.18,
          "close": 56301.43,
          "low": 53525.8,
          "high": 57188,
          "amount": 27665.828615324925,
          "vol": 1531700938.3928895,
          "count": 1186984
        },
        {
          "id": 1616428800,
          "open": 57080.04,
          "close": 55169.17,
          "low": 53000,
          "high": 57190,
          "amount": 28561.509198721455,
          "vol": 1563606444.669957,
          "count": 1307520
        },
        {
          "id": 1616342400,
          "open": 57160.75,
          "close": 57080.05,
          "low": 56272.26,
          "high": 58452.29,
          "amount": 17304.735920495983,
          "vol": 992309912.1155224,
          "count": 943411
        },
        {
          "id": 1616256000,
          "open": 59247.1,
          "close": 57160.76,
          "low": 55402.48,
          "high": 59470.72,
          "amount": 23626.080667226757,
          "vol": 1358082351.1489365,
          "count": 1043058
        },
        {
          "id": 1616169600,
          "open": 58970.73,
          "close": 59244.97,
          "low": 57822.03,
          "high": 59900,
          "amount": 17533.933469539832,
          "vol": 1031335970.8897314,
          "count": 891451
        },
        {
          "id": 1616083200,
          "open": 59531.58,
          "close": 58970.73,
          "low": 56200,
          "high": 60128.21,
          "amount": 25070.837878483675,
          "vol": 1461093427.6788812,
          "count": 1088620
        },
        {
          "id": 1615996800,
          "open": 54928.44,
          "close": 59531.57,
          "low": 54724.6,
          "high": 59600,
          "amount": 27349.13794778293,
          "vol": 1590043697.8375015,
          "count": 1220429
        },
        {
          "id": 1615910400,
          "open": 55839.07,
          "close": 54928.44,
          "low": 54129.81,
          "high": 57160,
          "amount": 21577.1125120589,
          "vol": 1198412270.3367848,
          "count": 1097667
        },
        {
          "id": 1615824000,
          "open": 56218.8,
          "close": 55838.97,
          "low": 53266,
          "high": 56932.54,
          "amount": 31689.857768905204,
          "vol": 1749608884.7009022,
          "count": 1374264
        },
        {
          "id": 1615737600,
          "open": 59681.18,
          "close": 56221.19,
          "low": 54550,
          "high": 60741.29,
          "amount": 38665.28396571959,
          "vol": 2225845294.9155955,
          "count": 1660910
        },
        {
          "id": 1615651200,
          "open": 59689.65,
          "close": 59678.11,
          "low": 59336.88,
          "high": 61800,
          "amount": 20329.372336215558,
          "vol": 1232066101.7469604,
          "count": 1098526
        },
        {
          "id": 1615564800,
          "open": 56953.07,
          "close": 59684.57,
          "low": 56090.73,
          "high": 60399,
          "amount": 29078.62820156748,
          "vol": 1692930349.38773,
          "count": 1472648
        },
        {
          "id": 1615478400,
          "open": 56345.33,
          "close": 56953.06,
          "low": 55033,
          "high": 58122,
          "amount": 26012.950744978592,
          "vol": 1475202444.986242,
          "count": 1328225
        },
        {
          "id": 1615392000,
          "open": 56317.56,
          "close": 56341.16,
          "low": 54259.43,
          "high": 57371.32,
          "amount": 29104.08347970015,
          "vol": 1629397106.0633624,
          "count": 1408449
        },
        {
          "id": 1615305600,
          "open": 54081.41,
          "close": 56310.75,
          "low": 53022.76,
          "high": 56466.94,
          "amount": 27121.225211060457,
          "vol": 1483463817.4158847,
          "count": 1145113
        },
        {
          "id": 1615219200,
          "open": 51057.69,
          "close": 54082.04,
          "low": 50550,
          "high": 54793.45,
          "amount": 29871.396155469905,
          "vol": 1591049846.4160414,
          "count": 1150047
        },
        {
          "id": 1615132800,
          "open": 50576.99,
          "close": 51052.51,
          "low": 49240.69,
          "high": 51838.65,
          "amount": 29095.558573521128,
          "vol": 1469753364.5684953,
          "count": 1089506
        },
        {
          "id": 1615046400,
          "open": 47273.25,
          "close": 50576.23,
          "low": 47120,
          "high": 51255.91,
          "amount": 23604.52282532572,
          "vol": 1174861251.4648151,
          "count": 898698
        },
        {
          "id": 1614960000,
          "open": 47867.29,
          "close": 47273.25,
          "low": 46900,
          "high": 49444,
          "amount": 20648.287971113772,
          "vol": 997751169.6938424,
          "count": 829058
        },
        {
          "id": 1614873600,
          "open": 49409.02,
          "close": 47867.29,
          "low": 46300.75,
          "high": 50058.78,
          "amount": 30252.33688301476,
          "vol": 1442908938.5362012,
          "count": 1160323
        },
        {
          "id": 1614787200,
          "open": 50780.6,
          "close": 49413.92,
          "low": 48513,
          "high": 51768.6,
          "amount": 34529.92296407207,
          "vol": 1727645324.1578937,
          "count": 1275916
        },
        {
          "id": 1614700800,
          "open": 48674.12,
          "close": 50780.61,
          "low": 47055,
          "high": 52637.83,
          "amount": 35862.93911292392,
          "vol": 1789697042.5727303,
          "count": 1267788
        },
        {
          "id": 1614614400,
          "open": 49185.51,
          "close": 48674.12,
          "low": 47900.01,
          "high": 50196.94,
          "amount": 31458.85104374805,
          "vol": 1540336754.0659935,
          "count": 1115394
        },
        {
          "id": 1614528000,
          "open": 43393.64,
          "close": 49185.51,
          "low": 43000,
          "high": 49281.49,
          "amount": 36936.92186571269,
          "vol": 1712666482.6568668,
          "count": 1249626
        },
        {
          "id": 1614441600,
          "open": 46532.82,
          "close": 43391.93,
          "low": 43177.77,
          "high": 47573.15,
          "amount": 35538.81053151816,
          "vol": 1602664100.1554618,
          "count": 1310750
        },
        {
          "id": 1614355200,
          "open": 47584.36,
          "close": 46530.01,
          "low": 45075,
          "high": 48419.4,
          "amount": 29196.253462001554,
          "vol": 1374936630.6259985,
          "count": 1226141
        },
        {
          "id": 1614268800,
          "open": 50840.79,
          "close": 47584.37,
          "low": 44111,
          "high": 51356,
          "amount": 52161.928090064604,
          "vol": 2454183013.7301273,
          "count": 1795117
        },
        {
          "id": 1614182400,
          "open": 49817.87,
          "close": 50840.97,
          "low": 48030,
          "high": 52000,
          "amount": 29203.115568046156,
          "vol": 1462954770.070855,
          "count": 1192696
        },
        {
          "id": 1614096000,
          "open": 48604.28,
          "close": 49814,
          "low": 45263.15,
          "high": 51350,
          "amount": 45755.28980002989,
          "vol": 2245886376.8649287,
          "count": 1865766
        },
        {
          "id": 1614009600,
          "open": 53231.54,
          "close": 48603.06,
          "low": 44918.29,
          "high": 54990,
          "amount": 86127.1417410079,
          "vol": 4249719903.411884,
          "count": 3046432
        },
        {
          "id": 1613923200,
          "open": 57316.36,
          "close": 53231.55,
          "low": 47650,
          "high": 58326.18,
          "amount": 54907.95549418052,
          "vol": 2965232380.5723605,
          "count": 2057229
        },
        {
          "id": 1613836800,
          "open": 56147.23,
          "close": 57315.36,
          "low": 53950,
          "high": 57822.08,
          "amount": 26081.082531499967,
          "vol": 1471583512.6460445,
          "count": 1208907
        },
        {
          "id": 1613750400,
          "open": 53807.9,
          "close": 56141.46,
          "low": 53301,
          "high": 57600,
          "amount": 24009.836807181502,
          "vol": 1342688888.4289958,
          "count": 1054452
        },
        {
          "id": 1613664000,
          "open": 51570.51,
          "close": 53807.9,
          "low": 50743.71,
          "high": 53807.9,
          "amount": 21596.626395409436,
          "vol": 1124023518.3061543,
          "count": 1019171
        },
        {
          "id": 1613577600,
          "open": 51159.83,
          "close": 51572.9,
          "low": 50790,
          "high": 52615.2,
          "amount": 23067.926927827935,
          "vol": 1194465664.9206874,
          "count": 955178
        },
        {
          "id": 1613491200,
          "open": 48958.14,
          "close": 51171.32,
          "low": 47768.11,
          "high": 51666,
          "amount": 37559.51242588549,
          "vol": 1879172694.6417162,
          "count": 1365184
        },
        {
          "id": 1613404800,
          "open": 47947.01,
          "close": 48958.14,
          "low": 47020,
          "high": 50580,
          "amount": 32994.37067263399,
          "vol": 1617223228.372327,
          "count": 1338485
        },
        {
          "id": 1613318400,
          "open": 48540.01,
          "close": 47947.01,
          "low": 45688.66,
          "high": 49288.93,
          "amount": 28227.948332818858,
          "vol": 1341665054.2667305,
          "count": 1378243
        },
        {
          "id": 1613232000,
          "open": 47083.47,
          "close": 48546.17,
          "low": 46659.8,
          "high": 49700,
          "amount": 24531.50240547786,
          "vol": 1184309955.5825732,
          "count": 1133187
        },
        {
          "id": 1613145600,
          "open": 47028.99,
          "close": 47082.76,
          "low": 46230,
          "high": 48100,
          "amount": 21722.636550069175,
          "vol": 1026625934.8755523,
          "count": 1124491
        },
        {
          "id": 1613059200,
          "open": 47951.56,
          "close": 47018.46,
          "low": 46160.69,
          "high": 48974.35,
          "amount": 28321.799012674124,
          "vol": 1346367404.3166592,
          "count": 1303378
        },
        {
          "id": 1612972800,
          "open": 44354.82,
          "close": 47951.62,
          "low": 43763.78,
          "high": 48348.4,
          "amount": 33972.4991569655,
          "vol": 1545823989.2060742,
          "count": 1449827
        },
        {
          "id": 1612886400,
          "open": 46773.2,
          "close": 44345.23,
          "low": 43729.11,
          "high": 47478.45,
          "amount": 37819.55658507264,
          "vol": 1742762607.735581,
          "count": 1639463
        },
        {
          "id": 1612800000,
          "open": 43647.6,
          "close": 46784.38,
          "low": 42530.75,
          "high": 48126.35,
          "amount": 51975.4161275267,
          "vol": 2378637974.9355874,
          "count": 1783339
        },
        {
          "id": 1612713600,
          "open": 37929.22,
          "close": 43660.05,
          "low": 37351,
          "high": 44195.33,
          "amount": 51225.490296113945,
          "vol": 2092405415.8691099,
          "count": 1635448
        },
        {
          "id": 1612627200,
          "open": 40846.82,
          "close": 37924.4,
          "low": 37583.19,
          "high": 40963.73,
          "amount": 34236.90946705199,
          "vol": 1338374457.2069767,
          "count": 1216587
        },
        {
          "id": 1612540800,
          "open": 37951.81,
          "close": 40849.89,
          "low": 37241.37,
          "high": 40850,
          "amount": 38216.85693345002,
          "vol": 1494912624.7865715,
          "count": 1356005
        },
        {
          "id": 1612454400,
          "open": 36560.56,
          "close": 37952.37,
          "low": 36398.52,
          "high": 38256.95,
          "amount": 27665.497973066584,
          "vol": 1034045538.1208371,
          "count": 1121676
        },
        {
          "id": 1612368000,
          "open": 36844.29,
          "close": 36564.58,
          "low": 36161.18,
          "high": 38696.38,
          "amount": 41350.56167293887,
          "vol": 1548491353.42769,
          "count": 1355672
        },
        {
          "id": 1612281600,
          "open": 34719.71,
          "close": 36847.6,
          "low": 34573.02,
          "high": 36920,
          "amount": 30025.84584606207,
          "vol": 1078394106.9971442,
          "count": 993521
        },
        {
          "id": 1612195200,
          "open": 33156.56,
          "close": 34719.71,
          "low": 33144,
          "high": 35650,
          "amount": 30005.602678376024,
          "vol": 1029611412.1199853,
          "count": 995684
        },
        {
          "id": 1612108800,
          "open": 32853.37,
          "close": 33156.65,
          "low": 32168.08,
          "high": 34678,
          "amount": 38156.91552972625,
          "vol": 1278421387.426902,
          "count": 1328802
        },
        {
          "id": 1612022400,
          "open": 34210.7,
          "close": 32858.22,
          "low": 32540.01,
          "high": 34774.99,
          "amount": 29648.583818143852,
          "vol": 1000421373.6512046,
          "count": 1107739
        },
        {
          "id": 1611936000,
          "open": 37118.83,
          "close": 34212.01,
          "low": 32837.11,
          "high": 37536.77,
          "amount": 56622.138228794676,
          "vol": 1951289465.987576,
          "count": 1702968
        },
        {
          "id": 1611849600,
          "open": 31924.16,
          "close": 37118.83,
          "low": 31651,
          "high": 38538,
          "amount": 97936.49322522334,
          "vol": 3435618904.8118324,
          "count": 2452416
        },
        {
          "id": 1611763200,
          "open": 30327.17,
          "close": 31924.17,
          "low": 29500,
          "high": 32200,
          "amount": 41067.00505619417,
          "vol": 1274692862.5890415,
          "count": 1365743
        },
        {
          "id": 1611676800,
          "open": 31753.45,
          "close": 30327.18,
          "low": 29231.31,
          "high": 32913.34,
          "amount": 46880.16477249009,
          "vol": 1463141082.0332294,
          "count": 1333915
        },
        {
          "id": 1611590400,
          "open": 34463.18,
          "close": 31757.38,
          "low": 30820,
          "high": 34642.19,
          "amount": 45794.61633696549,
          "vol": 1478941377.2430084,
          "count": 1414467
        },
        {
          "id": 1611504000,
          "open": 31952.58,
          "close": 34459.95,
          "low": 30915.05,
          "high": 34851,
          "amount": 42069.9272777947,
          "vol": 1387940620.1183274,
          "count": 1172805
        },
        {
          "id": 1611417600,
          "open": 31874.51,
          "close": 31952.8,
          "low": 31570.24,
          "high": 33086.94,
          "amount": 26076.20982331954,
          "vol": 844364199.9077648,
          "count": 835132
        },
        {
          "id": 1611331200,
          "open": 32457.33,
          "close": 31876.57,
          "low": 31390,
          "high": 33809.97,
          "amount": 35448.00603814852,
          "vol": 1155369348.6517293,
          "count": 1174269
        },
        {
          "id": 1611244800,
          "open": 31392.33,
          "close": 32457.32,
          "low": 28800,
          "high": 32736.99,
          "amount": 76447.54771846629,
          "vol": 2375752986.319357,
          "count": 2035734
        },
        {
          "id": 1611158400,
          "open": 34183.42,
          "close": 31392.34,
          "low": 31000.05,
          "high": 35666,
          "amount": 60531.03728420908,
          "vol": 2017056543.0242136,
          "count": 1775119
        },
        {
          "id": 1611072000,
          "open": 37328.33,
          "close": 34183.43,
          "low": 34000,
          "high": 37875,
          "amount": 43320.88729069178,
          "vol": 1540837836.045231,
          "count": 1471088
        },
        {
          "id": 1610985600,
          "open": 36408.32,
          "close": 37328.12,
          "low": 35398,
          "high": 37527.61,
          "amount": 34469.328152627655,
          "vol": 1265799903.763828,
          "count": 1162175
        },
        {
          "id": 1610899200,
          "open": 35731.78,
          "close": 36408.31,
          "low": 34778.15,
          "high": 37495.77,
          "amount": 32429.462984732443,
          "vol": 1171918542.3130214,
          "count": 1131119
        },
        {
          "id": 1610812800,
          "open": 37460.76,
          "close": 35732.04,
          "low": 33855.94,
          "high": 37749.5,
          "amount": 38072.08973234603,
          "vol": 1354974312.8487377,
          "count": 1351342
        },
        {
          "id": 1610726400,
          "open": 35627.27,
          "close": 37460.76,
          "low": 34359.8,
          "high": 37946.24,
          "amount": 47710.681399668254,
          "vol": 1734550702.1408982,
          "count": 1588039
        },
        {
          "id": 1610640000,
          "open": 39551.88,
          "close": 35627.27,
          "low": 35262.13,
          "high": 40036.29,
          "amount": 47620.31127283427,
          "vol": 1819115876.3318949,
          "count": 1504967
        },
        {
          "id": 1610553600,
          "open": 34677.02,
          "close": 39551.87,
          "low": 34392.15,
          "high": 40131,
          "amount": 50622.01595978496,
          "vol": 1908447757.5854213,
          "count": 1462606
        },
        {
          "id": 1610467200,
          "open": 33833.09,
          "close": 34677.01,
          "low": 32366,
          "high": 35545.46,
          "amount": 64569.5261057417,
          "vol": 2199675907.85375,
          "count": 1861143
        },
        {
          "id": 1610380800,
          "open": 31579.9,
          "close": 33834.78,
          "low": 30408,
          "high": 36643.21,
          "amount": 94077.7714047003,
          "vol": 3186467106.2154455,
          "count": 2661114
        },
        {
          "id": 1610294400,
          "open": 39674.77,
          "close": 31580.01,
          "low": 31091.41,
          "high": 39759,
          "amount": 117668.90845572227,
          "vol": 4140587450.6138873,
          "count": 3390203
        },
        {
          "id": 1610208000,
          "open": 40513.11,
          "close": 39674.77,
          "low": 38500,
          "high": 41350,
          "amount": 34751.114784318175,
          "vol": 1397070356.2042906,
          "count": 1362111
        },
        {
          "id": 1610121600,
          "open": 40830.8,
          "close": 40513.11,
          "low": 38600,
          "high": 41617.55,
          "amount": 43264.80315759802,
          "vol": 1739953122.1436727,
          "count": 1500553
        },
        {
          "id": 1610035200,
          "open": 38950,
          "close": 40829.87,
          "low": 36519.67,
          "high": 41900,
          "amount": 76574.66914283979,
          "vol": 2996968513.5285563,
          "count": 2212195
        },
        {
          "id": 1609948800,
          "open": 34558.52,
          "close": 38950,
          "low": 34277.24,
          "high": 38950,
          "amount": 52049.32802197474,
          "vol": 1910647166.1405544,
          "count": 1575604
        },
        {
          "id": 1609862400,
          "open": 32091.46,
          "close": 34555.33,
          "low": 31767.96,
          "high": 35781,
          "amount": 51275.45889797106,
          "vol": 1753138459.1916218,
          "count": 1528818
        },
        {
          "id": 1609776000,
          "open": 31741.01,
          "close": 32091.45,
          "low": 29901.56,
          "high": 32833.01,
          "amount": 49663.01730020864,
          "vol": 1559514990.333567,
          "count": 1393383
        },
        {
          "id": 1609689600,
          "open": 33506.67,
          "close": 31737.83,
          "low": 27777,
          "high": 33860.36,
          "amount": 79897.06557938721,
          "vol": 2525464505.2528224,
          "count": 2065934
        },
        {
          "id": 1609603200,
          "open": 31695.15,
          "close": 33506.67,
          "low": 30500,
          "high": 34762.8,
          "amount": 59882.65700510164,
          "vol": 1975612870.4242034,
          "count": 1641875
        },
        {
          "id": 1609516800,
          "open": 29190.92,
          "close": 31695.17,
          "low": 28631.09,
          "high": 31800.96,
          "amount": 36273.674734043714,
          "vol": 1089077873.408066,
          "count": 915648
        },
        {
          "id": 1609430400,
          "open": 28779.15,
          "close": 29190.91,
          "low": 28316.19,
          "high": 29619,
          "amount": 29516.27551081098,
          "vol": 859367434.7431436,
          "count": 882151
        },
        {
          "id": 1609344000,
          "open": 28153.95,
          "close": 28779.14,
          "low": 27851,
          "high": 29306.8,
          "amount": 42286.911158413925,
          "vol": 1212771208.7895503,
          "count": 1180194
        },
        {
          "id": 1609257600,
          "open": 26617.04,
          "close": 28153.95,
          "low": 26242.37,
          "high": 28597.77,
          "amount": 41877.39251834784,
          "vol": 1156219803.0824797,
          "count": 1242346
        },
        {
          "id": 1609171200,
          "open": 26911.93,
          "close": 26617.04,
          "low": 25888.88,
          "high": 27238.09,
          "amount": 35759.57827832906,
          "vol": 954118085.0018859,
          "count": 1103702
        },
        {
          "id": 1609084800,
          "open": 27360.51,
          "close": 26911.93,
          "low": 25838.46,
          "high": 27522.01,
          "amount": 40720.165605934184,
          "vol": 1094377862.1513357,
          "count": 1372876
        },
        {
          "id": 1608998400,
          "open": 25625.25,
          "close": 27360.51,
          "low": 25579.73,
          "high": 28424.49,
          "amount": 61967.340119426626,
          "vol": 1673845008.9005828,
          "count": 1699563
        },
        {
          "id": 1608912000,
          "open": 24019.43,
          "close": 25625.24,
          "low": 23989.26,
          "high": 25671.11,
          "amount": 30381.089452960972,
          "vol": 753224659.1980844,
          "count": 930980
        },
        {
          "id": 1608825600,
          "open": 23230.15,
          "close": 24019.43,
          "low": 23112.17,
          "high": 24682.89,
          "amount": 35079.794814719426,
          "vol": 838619558.8296388,
          "count": 1022287
        },
        {
          "id": 1608739200,
          "open": 23451.47,
          "close": 23230.15,
          "low": 22616,
          "high": 23681.85,
          "amount": 35955.159517535925,
          "vol": 833001068.0416579,
          "count": 1207140
        },
        {
          "id": 1608652800,
          "open": 23341.64,
          "close": 23450.3,
          "low": 22693,
          "high": 24150.65,
          "amount": 47351.80078235233,
          "vol": 1115353837.8856664,
          "count": 1325203
        },
        {
          "id": 1608566400,
          "open": 23101.17,
          "close": 23341.65,
          "low": 22373.62,
          "high": 23639.91,
          "amount": 39020.01909889553,
          "vol": 894560870.622845,
          "count": 1007627
        },
        {
          "id": 1608480000,
          "open": 23873.03,
          "close": 23099.56,
          "low": 21906,
          "high": 24288,
          "amount": 50815.97493057572,
          "vol": 1179334434.7753513,
          "count": 1211292
        },
        {
          "id": 1608393600,
          "open": 23551.07,
          "close": 23873.04,
          "low": 23084.24,
          "high": 24188,
          "amount": 31134.46852206479,
          "vol": 736527235.1385266,
          "count": 868203
        },
        {
          "id": 1608307200,
          "open": 22553.91,
          "close": 23551.1,
          "low": 22450,
          "high": 23650,
          "amount": 24871.515138078754,
          "vol": 572969661.7792631,
          "count": 672051
        },
        {
          "id": 1608220800,
          "open": 23330.93,
          "close": 22553.6,
          "low": 22321,
          "high": 23705.83,
          "amount": 50334.62643337145,
          "vol": 1156181620.574877,
          "count": 1087307
        },
        {
          "id": 1608134400,
          "open": 20659.69,
          "close": 23329.31,
          "low": 20550,
          "high": 23850.21,
          "amount": 76399.10378397637,
          "vol": 1690988222.2536244,
          "count": 1272363
        },
        {
          "id": 1608048000,
          "open": 19406.29,
          "close": 20659.69,
          "low": 19280,
          "high": 20722,
          "amount": 42322.8338153864,
          "vol": 843717660.168786,
          "count": 675684
        },
        {
          "id": 1607961600,
          "open": 19198.23,
          "close": 19406.28,
          "low": 19050,
          "high": 19570,
          "amount": 24827.57151056751,
          "vol": 479026377.6357638,
          "count": 418078
        },
        {
          "id": 1607875200,
          "open": 19215.35,
          "close": 19198.7,
          "low": 18986.65,
          "high": 19392.19,
          "amount": 21712.140611461724,
          "vol": 416396392.68976206,
          "count": 338496
        },
        {
          "id": 1607788800,
          "open": 18401.98,
          "close": 19215.36,
          "low": 18366.25,
          "high": 19419,
          "amount": 31136.38959496791,
          "vol": 592905128.1028067,
          "count": 419031
        }
      ]
    };
    final list = parseJson['data'] as List<dynamic>;
    datas = list
        .map((item) {
      KLineEntity k = KLineEntity.fromJson(item as Map<String, dynamic>);
      k.time = item['id'];
      return k;
    })
        .toList()
        .reversed
        .toList()
        .cast<KLineEntity>();
    DataUtil.calculate(datas);
    showLoading = false;
    Future.delayed(Duration(seconds: 3),(){
      setState(() {
        //print('${datas}');
      });
    });
    // final Future<String> future = getIPAddress(period);
    // future.then((String result) {
    //   final Map parseJson = json.decode(result) as Map<dynamic, dynamic>;
    //   final list = parseJson['data'] as List<dynamic>;
    //   datas = list
    //       .map((item) => KLineEntity.fromJson(item as Map<String, dynamic>))
    //       .toList()
    //       .reversed
    //       .toList()
    //       .cast<KLineEntity>();
    //   DataUtil.calculate(datas!);
    //   showLoading = false;
    //   setState(() {});
    // }).catchError((_) {
    //   showLoading = false;
    //   setState(() {});
    //   print('### datas error $_');
    // });
  }

  // //获取火币数据，需要翻墙
  // Future<String> getIPAddress(String? period) async {
  //   var url =
  //       'https://api.huobi.br.com/market/history/kline?period=${period ?? '1day'}&size=300&symbol=btcusdt';
  //   late String result;
  //   final response = await http.get(Uri.parse(url));
  //   if (response.statusCode == 200) {
  //     result = response.body;
  //   } else {
  //     print('Failed getting IP address');
  //   }
  //   return result;
  // }
}
